@@ -12,13 +12,17 @@ OC.L10N.register(
     "Missing a temporary folder" : "Ontbrekende tydelike gids",
     "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
     "Cancel" : "Kanselleer",
+    "Close" : "Sluit",
     "File already exists" : "Lêer bestaan reeds",
     "Details" : "Besonderhede",
     "Tags" : "Etikette",
+    "No participants found" : "Geen deelnemers gevind",
     "Can edit" : "Kan redigeer",
     "Can share" : "Kan deel",
+    "Owner" : "Eienaar",
     "Delete" : "Skrap",
     "Edit" : "Wysig",
+    "Download" : "Laai af",
     "Comments" : "Kommentare",
     "Modified" : "Gewysig",
     "Created" : "Geskep",
@@ -32,7 +36,9 @@ OC.L10N.register(
     "Description" : "Beskrywing",
     "seconds ago" : "sekondes gelede",
     "Shared with you" : "Met u gedeel",
+    "No notifications" : "Geen kennisgewings",
     "An error occurred" : "'n Fout het voorgekom",
+    "Share" : "Deel",
     "This week" : "Vandeesweek"
 },
 "nplurals=2; plural=(n != 1);");
