@@ -168,8 +168,10 @@ OC.L10N.register(
     "Can edit" : "يمكن تعديله",
     "Can share" : "يمكن مشاركته",
     "Can manage" : "يمكن إدارته",
+    "Owner" : "المالك",
     "Delete" : "حذف ",
     "Failed to create share with {displayName}" : "فشل في إنشاء المشاركة مع {displayName}",
+    "Transfer" : "نقل",
     "Add a new list" : "اضف قائمة جديدة",
     "Archive all cards" : "أرشفة جميع البطاقات ",
     "Delete list" : "حذف القائمة",
@@ -186,6 +188,7 @@ OC.L10N.register(
     "Share from Files" : "مشاركة من الملفات",
     "Add this attachment" : "إضافة هذا المرفق",
     "Show in Files" : "عرض في الملفات ",
+    "Download" : "تنزيل",
     "Delete Attachment" : "مسح المرفق",
     "Restore Attachment" : "إستعادة المرفق",
     "File to share" : "ملف للمشاركة",
@@ -209,6 +212,8 @@ OC.L10N.register(
     "Select Date" : "اختر التاريخ ",
     "Today" : "اليوم",
     "Tomorrow" : "غدا",
+    "Next week" : "الاسبوع القادم",
+    "Next month" : "الشهر القادم",
     "Save" : "حفظ",
     "The comment cannot be empty." : "التعليق لايمكن ان يكون فارغا.",
     "The comment cannot be longer than 1000 characters." : "التعليق لا يمكن ان يكون اطول من 1000 حرف.",
