@@ -7,13 +7,16 @@ OC.L10N.register(
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
     "Cancel" : "Diddymu",
+    "Close" : "Cau",
     "Details" : "Manylion",
     "Tags" : "Tagiau",
     "Undo" : "Dadwneud",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Owner",
     "Delete" : "Dileu",
     "Edit" : "Golygu",
+    "Download" : "Llwytho i lawr",
     "Modified" : "Addaswyd",
     "Select Date" : "Dewis Dyddiad",
     "Today" : "Heddiw",
@@ -23,6 +26,7 @@ OC.L10N.register(
     "seconds ago" : "eiliad yn ôl",
     "Shared with you" : "Shared with you",
     "An error occurred" : "Digwyddodd gwall",
+    "Share" : "Rhannu",
     "This week" : "Wythnos yma"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
