@@ -5,6 +5,7 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
+    "%s on %s" : "%s en %s",
     "Finished" : "Terminado",
     "To review" : "Para revisar",
     "Action needed" : "Acción requerida",
@@ -19,7 +20,9 @@ OC.L10N.register(
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "Could not write file to disk" : "No fue posible escribir a disco",
     "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
+    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Add card" : "Agregar tarjeta",
@@ -31,9 +34,11 @@ OC.L10N.register(
     "Undo" : "Deshacer",
     "Can edit" : "Puede editar",
     "Can share" : "Puede compartir",
+    "Owner" : "Dueño",
     "Delete" : "Borrar",
     "Edit" : "Editar",
     "Members" : "Miembros",
+    "Download" : "Descargar",
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
@@ -52,6 +57,11 @@ OC.L10N.register(
     "Shared with you" : "Compartido con usted",
     "Board details" : "Detalles del tablero",
     "Edit board" : "Editar el tablero",
+    "Unarchive board" : "Desarchivar tablero",
+    "Archive board" : "Archivar tablero",
+    "No notifications" : "No hay notificaciones",
+    "Delete board" : "Borrar tableros",
+    "Share" : "Compartir",
     "This week" : "Esta semana"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
