@@ -67,4 +67,4 @@ OC.L10N.register(
     "Share" : "Compartir",
     "This week" : "Esta semana"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
