@@ -9,20 +9,26 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
     "No file was uploaded" : "Ühtegi faili ei latud üles",
     "Missing a temporary folder" : "Ajutine kausta on puudu",
+    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
     "Cancel" : "Loobu",
+    "Close" : "Sulge",
     "Details" : "Üksikasjad",
     "Sharing" : "Jagamine",
     "Tags" : "Sildid",
     "Can edit" : "Võib redigeerida",
     "Can share" : "Can share",
+    "Owner" : "Omanik",
     "Delete" : "Kustuta",
     "Edit" : "Redigeeri",
+    "Download" : "Lae alla",
     "Comments" : "Kommentaarid",
     "Modified" : "Muudetud",
     "Created" : "Loodud",
     "Due date" : "Tähtaeg",
     "Today" : "Täna",
     "Tomorrow" : "Homme",
+    "Next week" : "Järgmine nädal",
+    "Next month" : "Järgmine kuu",
     "Save" : "Salvesta",
     "Reply" : "Vasta",
     "Update" : "Uuenda",
@@ -31,6 +37,8 @@ OC.L10N.register(
     "Delete card" : "Kustuta kaart",
     "seconds ago" : "sekundit tagasi",
     "Shared with you" : "Sinuga jagatud",
-    "An error occurred" : "Tekkis tõrge"
+    "No notifications" : "Märguandeid pole",
+    "An error occurred" : "Tekkis tõrge",
+    "Share" : "Jaga"
 },
 "nplurals=2; plural=(n != 1);");
