@@ -106,6 +106,8 @@ OC.L10N.register(
     "Select a board" : "נא לבחור לוח",
     "Select a list" : "בחר רשימה",
     "Cancel" : "ביטול",
+    "Close" : "סגירה",
+    "Create card" : "יצירת כרטיס",
     "Select a card" : "נא לבחור כרטיס",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
@@ -155,8 +157,10 @@ OC.L10N.register(
     "Can edit" : "ניתן לערוך",
     "Can share" : "Can share",
     "Can manage" : "הרשאת ניהול",
+    "Owner" : "בעלות",
     "Delete" : "מחיקה",
     "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
+    "Transfer" : "העברה",
     "Add a new list" : "הוסף רשימה חדשה",
     "Archive all cards" : "ארכיב את כל הכרטיסים",
     "Delete list" : "מחיקת רשימה",
@@ -173,6 +177,7 @@ OC.L10N.register(
     "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
     "Show in Files" : "הצגה בקבצים",
+    "Download" : "הורדה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
     "File to share" : "קובץ לשיתוף",
@@ -195,6 +200,8 @@ OC.L10N.register(
     "Select Date" : "בחירת תאריך",
     "Today" : "היום",
     "Tomorrow" : "מחר",
+    "Next week" : "השבוע הבא",
+    "Next month" : "החודש הבא",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
@@ -218,6 +225,7 @@ OC.L10N.register(
     "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card to another board" : "העברת כרטיס ללוח אחר",
+    "List is empty" : "הרשימה ריקה",
     "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
     "All boards" : "כל הלוחות",
@@ -247,6 +255,7 @@ OC.L10N.register(
     "Delete the board?" : "למחוק את הלוח הזה?",
     "Loading filtered view" : "טוען תצוגה מסוננת",
     "No due" : "אין תאריך יעד",
+    "No results found" : "לא נמצאו תוצאות",
     "No upcoming cards" : "אין כרטיסים עתידיים",
     "upcoming cards" : "כרטיסים עתידיים",
     "Link to a board" : "קישור ללוח",
