@@ -4,19 +4,23 @@ OC.L10N.register(
     "Personal" : "Անձնական",
     "Done" : "Done",
     "Cancel" : "ընդհատել",
+    "Close" : "Փակել",
     "Details" : "Մանրամասներ",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Owner",
     "Delete" : "հեռացնել",
     "Edit" : "մշակել",
+    "Download" : "Ներբեռնել",
     "Comments" : "Կարծիքներ",
     "Modified" : "Փոփոխված",
+    "Today" : "այսօր",
     "Save" : "Պահպանել",
     "Update" : "Թարմացնել",
     "Description" : "Նկարագրություն",
     "seconds ago" : "վրկ. առաջ",
     "Shared with you" : "Shared with you",
-    "Today" : "այսօր",
+    "Share" : "Կիսվել",
     "This week" : "այս շաբաթ"
 },
 "nplurals=2; plural=(n != 1);");
