@@ -70,9 +70,13 @@ OC.L10N.register(
     "Upcoming cards" : "今後のカード",
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} さんが、{deck-board} で、あなたにカード「{deck-card}」を割り当てました。",
     "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
+    "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board}上のカード「{deck-card}」は、期日を迎えました。",
     "%s has mentioned you in a comment on \"%s\"." : "%sさんは \"%s\"へのコメントであなたについて言及しました。",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} さんが 「{deck-card}」のコメント内であなたについて言及しました。",
     "The board \"%s\" has been shared with you by %s." : "\"%s\" ボードは、%s からあなたに共有されています。",
+    "{user} has shared {deck-board} with you." : "{user} さんが、あなたと {deck-board} を共有しました。",
     "Card comments" : "カードコメント",
     "%s on %s" : "%s が %s で",
     "No data was provided to create an attachment." : "添付ファイルを作成するためのデータは提供されていません。",
@@ -96,10 +100,12 @@ OC.L10N.register(
     "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
     "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
+    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "このコメントは、%s 文字以上含まれています。\n%sという名前で、カードに添付ファイルとして追加しました。\n次のURLでアクセス可能です: %s",
     "Card not found" : "カードが見つかりません",
     "Path is already shared with this card" : "パスは既にこのカードで共有されています",
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
     "Card details" : "カード詳細",
     "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
@@ -110,6 +116,8 @@ OC.L10N.register(
     "Select a list" : "リストを選択",
     "Card title" : "カードのタイトル",
     "Cancel" : "キャンセル",
+    "Creating the new card …" : "新しいカードを作成しています...",
+    "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
     "Open card" : "カードを開く",
     "Close" : "閉じる",
     "Create card" : "カードを作成",
@@ -127,6 +135,7 @@ OC.L10N.register(
     "Archived cards" : "カードをアーカイブ",
     "Add list" : "リストを追加",
     "List name" : "リスト名",
+    "Active filters" : "有効なフィルター",
     "Apply filter" : "フィルターを適用",
     "Filter by tag" : "タグによるフィルター",
     "Filter by assigned user" : "割当ユーザーでフィルター",
@@ -162,8 +171,14 @@ OC.L10N.register(
     "Can edit" : "編集可能",
     "Can share" : "共有可能",
     "Can manage" : "管理可能",
+    "Owner" : "所有者",
     "Delete" : "削除",
     "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
+    "Are you sure you want to transfer the board {title} to {user}?" : "本当にボード {title} を {user} に転送しますか？",
+    "Transfer the board." : "ボードを転送します。",
+    "Transfer" : "転送",
+    "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
+    "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
     "Add a new list" : "新しいリストを追加",
     "Archive all cards" : "すべてのカードをアーカイブする",
     "Delete list" : "リストを削除",
@@ -178,9 +193,11 @@ OC.L10N.register(
     "Members" : "メンバー",
     "Upload new files" : "新しいファイルをアップロード",
     "Share from Files" : "ファイルから共有",
+    "Pending share" : "共有を保留中",
     "Add this attachment" : "この添付ファイルを追加",
     "Show in Files" : "ファイルに表示",
     "Download" : "ダウンロード",
+    "Remove attachment" : "添付ファイルを削除",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
     "File to share" : "共有するファイル",
@@ -193,6 +210,7 @@ OC.L10N.register(
     "Created" : "作成時刻",
     "The title cannot be empty." : "タイトルを空にすることはできません。",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
+    "Failed to load comments" : "コメントの読み込みに失敗しました",
     "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
     "Assign to users" : "ユーザーに割り当てる",
     "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
@@ -222,6 +240,7 @@ OC.L10N.register(
     "Write a description …" : "説明を書く…",
     "Choose attachment" : "添付ファイルを選択",
     "(group)" : "(グループ)",
+    "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Move card" : "カードの移動",
@@ -229,6 +248,7 @@ OC.L10N.register(
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
     "Move card to another board" : "カードを他のボードに移動",
+    "List is empty" : "リストが空です",
     "Card deleted" : "カードが削除されました",
     "seconds ago" : "数秒前",
     "All boards" : "すべてのボード",
@@ -274,6 +294,10 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
-    "This week" : "今週"
+    "Are you sure you want to transfer the board {title} for {user} ?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？",
+    "Transfer the board for {user} successfully" : "{user} のボードの転送に成功しました",
+    "Failed to transfer the board for {user}" : "{user} のボードの転送に失敗しました",
+    "This week" : "今週",
+    "Are you sure you want to transfer the board {title} for {user}?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？"
 },
 "nplurals=1; plural=0;");
