@@ -3,9 +3,11 @@ OC.L10N.register(
     {
     "You have created a new board {board}" : "새로운 보드{board}를 만들었습니다.",
     "Deck" : "덱",
+    "Upcoming cards" : "다음 카드들",
     "Personal" : "개인",
     "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
     "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
+    "%s on %s" : "%s(%s의)",
     "Finished" : "완료됨",
     "To review" : "리뷰할 항목",
     "Action needed" : "동작 필요",
@@ -24,12 +26,16 @@ OC.L10N.register(
     "Missing a temporary folder" : "임시 폴더 없음",
     "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
     "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
+    "Card not found" : "카드 없음",
+    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
     "Card details" : "카드 세부사항",
     "Add board" : "보드 추가",
     "Search by board title" : "보드 제목으로 검색",
     "Select board" : "보드 선택",
     "Select a board" : "보드 선택",
     "Cancel" : "취소",
+    "Close" : "닫기",
+    "Create card" : "크레딧 카드",
     "Select a card" : "카드 선택",
     "Select the card to link to a project" : "카드를 선택해 프로젝트에 연결",
     "File already exists" : "파일이 이미 존재함",
@@ -59,14 +65,23 @@ OC.L10N.register(
     "Sharing" : "공유",
     "Tags" : "태그",
     "Deleted items" : "삭제된 항목",
+    "Timeline" : "타임라인",
     "Undo" : "실행 취소",
+    "No participants found" : "참여자를 찾을 수 없음",
     "(Group)" : "(그룹)",
     "Can edit" : "편집할 수 있음",
     "Can share" : "공유할 수 있음",
+    "Owner" : "소유자",
     "Delete" : "삭제",
+    "Transfer" : "전송",
     "Delete list" : "목록 지우기",
     "Edit" : "편집",
     "Members" : "구성원",
+    "Upload new files" : "새로운 파일 업로드",
+    "Share from Files" : "파일 공유",
+    "Download" : "다운로드",
+    "File to share" : "공유할 파일",
+    "Invalid path selected" : "잘못된 경로가 선택됨",
     "Attachments" : "첨부파일",
     "Comments" : "댓글",
     "Modified" : "수정한 날짜",
@@ -76,25 +91,37 @@ OC.L10N.register(
     "Select Date" : "날짜 선택",
     "Today" : "오늘",
     "Tomorrow" : "내일",
+    "Next week" : "다음주",
+    "Next month" : "다음달",
     "Save" : "저장",
     "Reply" : "답장",
     "Update" : "업데이트",
     "Description" : "설명",
     "Formatting help" : "서식 도움말",
+    "Edit description" : "설명 편집",
     "(group)" : "(그룹)",
     "Move card" : "카드 이동",
     "Archive card" : "보관 카드",
     "Delete card" : "카드 삭제",
+    "List is empty" : "목록이 비어 있음",
     "seconds ago" : "초 전",
     "All boards" : "모든 보드",
     "Archived boards" : "보관된 게시판",
     "Shared with you" : "나와 공유됨",
     "Board details" : "게시판 정보",
     "Edit board" : "게시판 편집",
+    "Clone board" : "게시판 복제",
+    "Unarchive board" : "게시판 보관 해제",
+    "Archive board" : "게시판 보관",
+    "No notifications" : "알림 없음",
+    "Delete board" : "게시판 삭제",
+    "No reminder" : "알림 없음",
     "An error occurred" : "오류가 발생함",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "정말로 보드 {title}을 지우시겠습니까? 보드의 모든 데이터가 삭제됩니다.",
     "Delete the board?" : "보드를 삭제합니까?",
+    "No results found" : "결과 없음",
     "Something went wrong" : "잘못된 접근",
+    "Share" : "공유",
     "This week" : "이번 주"
 },
 "nplurals=1; plural=0;");
