@@ -7,8 +7,10 @@ OC.L10N.register(
     "To review" : "Дахин хянах",
     "Action needed" : "Үйлдэл шаардлагатай",
     "Later" : "Хойшлуулах",
+    "copy" : "Хуулах ",
     "Done" : "Хийсэн",
     "Cancel" : "болиулах",
+    "Close" : "Хаах",
     "Hide archived cards" : "Архивлагдсан картуудыг нуух",
     "Show archived cards" : "Архивлагдсан картуудыг харах",
     "Details" : "Дэлгэрэнгүй",
@@ -17,9 +19,11 @@ OC.L10N.register(
     "Undo" : "буцах",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Эзэмшигч",
     "Delete" : "Устгах",
     "Edit" : "Засварлах",
     "Members" : "Гишүүд",
+    "Download" : "Татах",
     "Attachments" : "Хавсралт",
     "Comments" : "Сэтгэгдлүүд",
     "Modified" : "Өөрчлөгдсөн",
@@ -33,6 +37,8 @@ OC.L10N.register(
     "(group)" : "(бүлэг)",
     "seconds ago" : "хоёрдахь өмнө",
     "Shared with you" : "тантай хуваалцсан",
+    "No notifications" : "Мэдэгдэл байхгүй",
+    "Share" : "Түгээх",
     "This week" : "7 хоног"
 },
 "nplurals=2; plural=(n != 1);");
