@@ -10,17 +10,22 @@ OC.L10N.register(
     "No file was uploaded" : "කිසිදු ගොනුවක් උඩුගත කර නොමැත",
     "Missing a temporary folder" : "තාවකාලික බහාලුමක් අස්ථානගත වී ඇත",
     "Cancel" : "අවලංගු කරන්න",
+    "Close" : "වසන්න",
     "File already exists" : "ගොනුව දැනටමත් පවතී",
     "Add list" : "ලැයිස්තුව එකතු කරන්න",
     "Details" : "විස්තර",
     "Undo" : "පෙරසේ",
     "(Group)" : "(සමූහය)",
+    "Owner" : "හිමිකරු",
     "Edit" : "සංස්කරණය",
+    "Download" : "බාගන්න",
     "Attachments" : "ඇමිණුම්",
     "Comments" : "අදහස්",
     "Select Date" : "දිනය තෝරන්න",
     "Today" : "අද",
     "Tomorrow" : "හෙට",
+    "Next week" : "ඊළඟ සතිය",
+    "Next month" : "ඊළඟ මාසය",
     "Save" : "සුරකින්න",
     "Reply" : "පිළිතුර",
     "Update" : "යාවත්කාල",
