@@ -6,6 +6,7 @@ OC.L10N.register(
     "Done" : "Done",
     "Add board" : "Dodaj tablu",
     "Cancel" : "Otkaži",
+    "Close" : "Zatvori",
     "Add card" : "Dodaj karticu",
     "Details" : "Detalji",
     "Sharing" : "Deljenje",
@@ -13,8 +14,10 @@ OC.L10N.register(
     "Undo" : "Opozovi",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Vlasnik",
     "Delete" : "Obriši",
     "Edit" : "Uredi",
+    "Download" : "Preuzmi",
     "Attachments" : "Prilozi",
     "Due date" : "Rok",
     "Today" : "Danas",
@@ -28,6 +31,10 @@ OC.L10N.register(
     "seconds ago" : "pre nekoliko sekundi",
     "Shared with you" : "Shared with you",
     "Edit board" : "Izmeni tablu",
+    "Archive board" : "Arhiviraj tablu",
+    "No notifications" : "Nema obaveštenja",
+    "Delete board" : "Izbriši tablu",
+    "Share" : "Podeli",
     "This week" : "Ove sedmice"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
