@@ -18,15 +18,18 @@ OC.L10N.register(
     "You have renamed the card {before} to {card}" : "Bạn đã thay đổi tên của tác vụ {before} thành {card}",
     "{user} has renamed the card {before} to {card}" : "{user} đã thay đổi tên của tác vụ {before} thành {card}",
     "Deck" : "Kế hoạch",
+    "Upcoming cards" : "Thẻ sắp đến",
     "Personal" : "Cá nhân",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Tác vụ \"%s\" trong \"%s\" đã được phân công cho bạn bởi  %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Tác vụ \"%s\" trong \"%s\" đã đến ngày hạn chót.",
     "The board \"%s\" has been shared with you by %s." : "Dự án \"%s\" đã được chia sẽ với bạn bởi %s .",
+    "%s on %s" : "%s trên %s",
     "No data was provided to create an attachment." : "Không có dữ liệu từ nhà cung cấp để tạo một đính kèm",
     "Finished" : "Đã hoàn tất",
     "To review" : "Xem thử",
     "Action needed" : "Cần thực hiện",
     "Later" : "Để sau",
+    "copy" : "sao chép",
     "To do" : "Cần làm",
     "Doing" : "Đang làm",
     "Done" : "Hoàn tất",
@@ -42,20 +45,45 @@ OC.L10N.register(
     "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
     "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
     "No file uploaded or file size exceeds maximum of %s" : "Chưa có tệp nào được tải lên hoặc kích thước tệp vượt quá giới hạn của %s",
+    "Card not found" : "Không tìm thấy thẻ",
+    "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
+    "Add board" : "Thêm dự án",
     "Cancel" : "Hủy bỏ",
+    "Close" : "Đóng",
+    "File already exists" : "Tệp đã tồn tại",
+    "Drop your files to upload" : "Thả tệp của bạn để tải lên",
     "Add card" : "Thêm tác vụ",
+    "Archived cards" : "Thẻ đã lưu trữ",
+    "Add list" : "Thêm danh sách",
+    "Filter by tag" : "Lọc theo nhãn",
+    "Filter by assigned user" : "Lọc theo người dùng được phân công",
+    "Unassigned" : "Chưa được phân công",
+    "Filter by due date" : "Lọc theo thời hạn",
+    "Overdue" : "Quá hạn",
+    "Next 7 days" : "7 ngày tiếp theo",
+    "Next 30 days" : "30 ngày tiếp theo",
+    "No due date" : "Không có thời hạn",
     "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
     "Show archived cards" : "Hiện tác vụ đã lưu trữ",
     "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
     "Details" : "Thông tin",
     "Sharing" : "Đang chia sẽ",
     "Tags" : "Thẻ",
+    "Undo" : "Hoàn tác",
     "Can edit" : "Có thể chỉnh sửa",
     "Can share" : "Can share",
+    "Owner" : "Chủ",
     "Delete" : "Xóa",
+    "Transfer" : "Truyền",
+    "Delete list" : "Xoá danh sách",
     "Add a new card" : "Thêm một tác vụ mới",
     "Edit" : "Chỉnh sửa",
     "Members" : "Thành viên",
+    "Upload new files" : "Tải lên các tệp mới",
+    "Share from Files" : "Chia sẻ từ Thư mục",
+    "Download" : "Tải xuống",
+    "File to share" : "Tệp để chia sẻ",
+    "Invalid path selected" : "‎Đường dẫn không hợp lệ được chọn‎",
     "Attachments" : "Đính kèm",
     "Comments" : "Các bình luận",
     "Modified" : "Thay đổi",
@@ -64,19 +92,35 @@ OC.L10N.register(
     "Remove due date" : "Xóa thời hạn",
     "Select Date" : "Chọn ngày",
     "Today" : "Hôm nay",
+    "Tomorrow" : "Ngày mai",
+    "Next week" : "Tuần sau",
+    "Next month" : "Tháng sau",
     "Save" : "Lưu",
     "Reply" : "Trả l",
     "Update" : "Cập nhật",
     "Description" : "Mô tả",
     "Formatting help" : "Định dạng trợ giúp",
+    "Edit description" : "Chỉnh sửa mô tả",
     "(group)" : "(nhóm)",
     "Assign to me" : "Phân công cho tôi",
+    "Move card" : "Di chuyển thẻ",
+    "Archive card" : "Lưu trữ thẻ",
+    "Delete card" : "Xoá thẻ",
+    "List is empty" : "Danh sách trống",
     "seconds ago" : "vài giây trước",
     "Archived boards" : "Dự án đã lưu trữ",
     "Shared with you" : "Đã chia sẻ với bạn",
     "Board details" : "Thông tin dự án",
     "Edit board" : "Chỉnh sửa dự án",
+    "Clone board" : "Nhân bản dự án",
+    "Unarchive board" : "Bỏ lưu trữ dự án",
+    "Archive board" : "Lưu trữ dự án",
+    "No notifications" : "Không có thông báo",
+    "Delete board" : "Xóa dự án",
+    "No reminder" : "Không có nhắc hẹn",
     "An error occurred" : "Có lỗi đã xảy ra",
-    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin"
+    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin",
+    "Share" : "Chia sẻ",
+    "This week" : "Tuần này"
 },
 "nplurals=1; plural=0;");
