@@ -24,9 +24,12 @@
 namespace OCA\Deck\Controller;
 
 use OCA\Deck\Db\Acl;
+use OCA\Deck\Db\Board;
 use OCA\Deck\Service\BoardService;
 use OCA\Deck\Service\PermissionService;
 use OCP\AppFramework\ApiController;
+use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\DataResponse;
 use OCP\IRequest;
 
 class BoardController extends ApiController {
@@ -150,9 +153,20 @@ class BoardController extends ApiController {
 	/**
 	 * @NoAdminRequired
 	 * @param $boardId
-	 * @return \OCP\Deck\DB\Board
+	 * @return Board
 	 */
 	public function clone($boardId) {
 		return $this->boardService->clone($boardId, $this->userId);
 	}
+
+	/**
+	 * @NoAdminRequired
+	 */
+	public function transferOwner(int $boardId, string $newOwner): DataResponse {
+		if ($this->permissionService->userIsBoardOwner($boardId, $this->userId)) {
+			return new DataResponse($this->boardService->transferBoardOwnership($boardId, $newOwner), HTTP::STATUS_OK);
+		}
+
+		return new DataResponse([], HTTP::STATUS_UNAUTHORIZED);
+	}
 }
