@@ -475,4 +475,34 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 			return null;
 		});
 	}
+
+	/**
+	 * @throws \OCP\DB\Exception
+	 */
+	public function transferOwnership(string $ownerId, string $newOwnerId, $boardId = null): void {
+		$qb = $this->db->getQueryBuilder();
+		$qb->update('deck_boards')
+			->set('owner', $qb->createNamedParameter($newOwnerId, IQueryBuilder::PARAM_STR))
+			->where($qb->expr()->eq('owner', $qb->createNamedParameter($ownerId, IQueryBuilder::PARAM_STR)));
+		if ($boardId !== null) {
+			$qb->andWhere($qb->expr()->eq('id', $qb->createNamedParameter($boardId, IQueryBuilder::PARAM_INT)));
+		}
+		$qb->executeStatement();
+	}
+
+	/**
+	 * Reset cache for a given board or a given user
+	 */
+	public function flushCache(?int $boardId = null, ?string $userId = null) {
+		if ($boardId) {
+			unset($this->boardCache[$boardId]);
+		} else {
+			$this->boardCache = null;
+		}
+		if ($userId) {
+			unset($this->userBoardCache[$userId]);
+		} else {
+			$this->userBoardCache = null;
+		}
+	}
 }
