@@ -27,6 +27,7 @@ declare(strict_types=1);
 namespace OCA\Deck\Sharing;
 
 use OC\Files\Cache\Cache;
+use OCA\Deck\Cache\AttachmentCacheHelper;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\Board;
 use OCA\Deck\Db\BoardMapper;
@@ -45,7 +46,6 @@ use OCP\Files\IMimeTypeLoader;
 use OCP\Files\Node;
 use OCP\IDBConnection;
 use OCP\IL10N;
-use OCP\Security\ISecureRandom;
 use OCP\Share\Exceptions\GenericShareException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager;
@@ -69,6 +69,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 	private $dbConnection;
 	/** @var IManager */
 	private $shareManager;
+	/** @var AttachmentCacheHelper */
+	private $attachmentCacheHelper;
 	/** @var BoardMapper */
 	private $boardMapper;
 	/** @var CardMapper */
@@ -77,14 +79,25 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 	private $permissionService;
 	/** @var ITimeFactory */
 	private $timeFactory;
+	/** @var IL10N */
 	private $l;
 
-	public function __construct(IDBConnection $connection, IManager $shareManager, ISecureRandom $secureRandom, BoardMapper $boardMapper, CardMapper $cardMapper, PermissionService $permissionService, IL10N $l) {
+	public function __construct(
+		IDBConnection $connection,
+		IManager $shareManager,
+		BoardMapper $boardMapper,
+		CardMapper $cardMapper,
+		PermissionService $permissionService,
+		AttachmentCacheHelper $attachmentCacheHelper,
+		IL10N $l
+	) {
 		$this->dbConnection = $connection;
 		$this->shareManager = $shareManager;
 		$this->boardMapper = $boardMapper;
 		$this->cardMapper = $cardMapper;
+		$this->attachmentCacheHelper = $attachmentCacheHelper;
 		$this->permissionService = $permissionService;
+
 		$this->l = $l;
 		$this->timeFactory = \OC::$server->get(ITimeFactory::class);
 	}
@@ -152,6 +165,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		);
 		$data = $this->getRawShare($shareId);
 
+		$this->attachmentCacheHelper->clearAttachmentCount((int)$cardId);
+
 		return $this->createShareObject($data);
 	}
 
@@ -339,6 +354,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		$qb->orWhere($qb->expr()->eq('parent', $qb->createNamedParameter($share->getId())));
 
 		$qb->execute();
+
+		$this->attachmentCacheHelper->clearAttachmentCount((int)$share->getSharedWith());
 	}
 
 	/**
